#!/bin/bash

#
# verbParallelEnvSetupParam.sh
#
#   memorizza nel file di output per la modalita' verbose, se attiva,
#   il valore dei parametri specificati per il setup dell'ambiente
#   di simulazione
#

#
# Parametri
#
# <verbose>
#   i valori ammessi per il parametro sono 0 o 1.
#   Se 1 attiva la modalita' verbose di esecuzione dello script
# <callingScript>
#   nome dello script chiamante
# <macroFileAbsolutePath>
#   path assoluto del file di macro a partire dal quale vengono generati
#   quelli per le simulazioni eseguite dai singoli job
# <setSeedsString>
#   stringa che nel file di macro individua la direttiva che setta
#   il seed per il generatore casuale di eventi
# <workingDirectoryRelativePath>
#   path relativo alla directory g4cParallelSimulation di quella
#   di lavoro che contiene le subdirectory assegnate ai job che
#   realizzano la simulazione, il file con le informazioni relative
#   ai loro istanti di sottomissione e di completamento e il file di
#   output per la modalita' verbose
# <totalNumberOfJobs>
#   numero totale dei job che realizzano la simulazione parallela.
#   Deve preferibilmente essere minore o uguale del numero di host
#   impegnati moltiplicato per il minimo numero di core che su ogni
#   host vengono riservati alla simulazione
# <verbOutputFileRelativePath>
#   path relativo alla directory g4cParallelSimulation del file
#   di output per la modalita' verbose
#

# Estrae i parametri dello script dalla sua chiamata
verbose=$1
macroFileAbsolutePath=$3
setSeedsString=$4
workingDirectoryRelativePath=$5
totalNumberOfJobs=$6
verbOutputFileRelativePath=$7

# Esce se la modalita' verbose non e' attiva
if test $verbose -eq 0
then
   exit 0
fi

# Memorizza nel file di output per la modalita verbose, se attiva,
# il valore dei parametri specificati per il setup 
# dell'ambiente di simulazione
cat <<  EOF >> $verbOutputFileRelativePath
Valore dei parametri
-
<macroFileAbsolutePath>: $macroFileAbsolutePath
<setSeedsString>: $setSeedsString
<workingDirectoryRelativePath>: $workingDirectoryRelativePath
<totalNumberOfJobs>: $totalNumberOfJobs

EOF

exit 0

